@@ -29,7 +29,8 @@ test_that("PDB annotation works", {
                 '3R1C_W', '3R1C_X', '3R1C_V', '3R1C_Z')
   
   invisible(capture.output(anno <- pdb.annotate('3R1C')))
-  expect_identical(rownames(anno), expected)
+  # 'sort' because sometimes PDB returns chain IDs in an uncertain way...
+  expect_identical(sort(rownames(anno)), sort(expected))
 
   expected <- c('3R1C_A', '3R1C_a', '3R1C_B', '3R1C_b',
                 '3R1C_C', '3R1C_c', '3R1C_D', '3R1C_d',
@@ -43,7 +44,8 @@ test_that("PDB annotation works", {
                 '1CDK_A', '1CDK_B', '1CDK_I', '1CDK_J')
   
   invisible(capture.output(anno <- pdb.annotate(c('3R1C', '1CDK'))))
-  expect_identical(rownames(anno), expected)
+  # 'sort' because sometimes PDB returns chain IDs in an uncertain way...
+  expect_identical(sort(rownames(anno)), sort(expected))
 
   expect_warning(  
     invisible(capture.output(anno <- pdb.annotate(c('3R1C_A', '3r1c_a', '3r1c_q'))))
@@ -59,5 +61,26 @@ test_that("PDB annotation works", {
   invisible(capture.output(anno <- pdb.annotate(c('1cdk_A', '1cdk_B'), anno.terms="ligandId")))
   expect_identical(sort(unlist(strsplit(anno$ligandId, ","))), expected)
 
+  ## Test cases without ligands
+  ids <- c("6AXG_B", "1AA9_A", "7L0F_A", "6AMB_A", "121P_A", "5E95_A")
+  invisible(capture.output(anno <- pdb.annotate(ids)))
+  expect_identical(paste(anno[, "structureId"], anno[, "chainId"], sep="_"), ids)
+  expect_true(is.na(anno[1, "ligandId"]))
+  expect_identical(anno[2, "experimentalTechnique"], "NMR")
+
+  ## Test cases without 'source'
+  ids <- c("1P79", "4os7")
+  invisible(capture.output(anno <- pdb.annotate(ids)))
+  expect_true(is.na(anno[1, "source"]))
+  expect_true(is.na(anno[3, "source"]))
+  expect_identical(anno[1, "macromoleculeType"], "RNA")
+  expect_identical(anno[3, "macromoleculeType"], "Protein")
   
+  ## Test cases with duplicated 'sources'
+  ids <- c("5TOK")
+  invisible(capture.output(anno <- pdb.annotate(ids)))
+  expect_identical(anno[1, "source"], "Human orthopneumovirus")
+
+  ## Test error handling
+  expect_error(pdb.annotate("1234"), regexp="No data retrieved")
 })
